==> kubernetes-model-apiextensions-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourceScaleBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceSubresourceScaleBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder>{
  public CustomResourceSubresourceScaleBuilder() {
    this(false);
  }
  public CustomResourceSubresourceScaleBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceSubresourceScale(), validationEnabled);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceSubresourceScale(), validationEnabled);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale instance) {
    this(fluent, instance, false);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLabelSelectorPath(instance.getLabelSelectorPath()); 
    fluent.withSpecReplicasPath(instance.getSpecReplicasPath()); 
    fluent.withStatusReplicasPath(instance.getStatusReplicasPath()); 
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale instance) {
    this(instance,false);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLabelSelectorPath(instance.getLabelSelectorPath()); 
    this.withSpecReplicasPath(instance.getSpecReplicasPath()); 
    this.withStatusReplicasPath(instance.getStatusReplicasPath()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale build() {
    CustomResourceSubresourceScale buildable = new CustomResourceSubresourceScale(fluent.getLabelSelectorPath(),fluent.getSpecReplicasPath(),fluent.getStatusReplicasPath());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceSubresourceScaleBuilder that = (CustomResourceSubresourceScaleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourceScaleBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceSubresourceScaleBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleBuilder>{
  public CustomResourceSubresourceScaleBuilder() {
    this(false);
  }
  public CustomResourceSubresourceScaleBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceSubresourceScale(), validationEnabled);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceSubresourceScale(), validationEnabled);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale instance) {
    this(fluent, instance, false);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLabelSelectorPath(instance.getLabelSelectorPath()); 
    fluent.withSpecReplicasPath(instance.getSpecReplicasPath()); 
    fluent.withStatusReplicasPath(instance.getStatusReplicasPath()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale instance) {
    this(instance,false);
  }
  public CustomResourceSubresourceScaleBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLabelSelectorPath(instance.getLabelSelectorPath()); 
    this.withSpecReplicasPath(instance.getSpecReplicasPath()); 
    this.withStatusReplicasPath(instance.getStatusReplicasPath()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScaleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceSubresourceScale build() {
    CustomResourceSubresourceScale buildable = new CustomResourceSubresourceScale(fluent.getLabelSelectorPath(),fluent.getSpecReplicasPath(),fluent.getStatusReplicasPath());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceSubresourceScaleBuilder that = (CustomResourceSubresourceScaleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
